; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |----------------------------------------------------------
; Please define Anim 74140108 in your AIR file if AND ONLY IF you place these
; 7 Hold Button commands immediately after the 11 Single Button and Hold Dir
; commands at the very top of your CMD list, as demonstrated here.
; In this version of the AI code, these commands are only used by the XOR
; method, and thus are optional.  But there remains a possibility that a
; future version of the helper method might be helped by having these
; commands placed here, and Anim 74140108 would then be used to indicate
; that a partner character has a compatible CMD.

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdstart"
command = /s
time = 1

;--- None of your own command definitions should be above this line. ---

;-| CPU |--------------------------------------------------------------
; Note that if you make any changes to the basic one-button or recovery
; commands, you'll need to make the same changes to their matching commands here
; and/or in the XOR VarSet controller.  That includes things like, for example:
;  * changing the recovery command to use a different combination of buttons.
;  * renaming the b button command as "d", or the start button command as "s".
;  * switching the button names around, e.g. so button y triggers "a" and button a triggers "y".
;  * having more than one way to trigger the same command name.
; If you understand how the XOR method works, the proper changes should be obvious.
; If you don't understand it, then simply disable the lines in the XOR VarSet
; controller that correspond to the commands you've altered.

[Command]
name = "a2"
command = a
time = 1

[Command]
name = "b2"
command = b
time = 1

[Command]
name = "c2"
command = c
time = 1

[Command]
name = "x2"
command = x
time = 1

[Command]
name = "y2"
command = y
time = 1

[Command]
name = "z2"
command = z
time = 1

[Command]
name = "start2"
command = s
time = 1

[Command]
name = "holdfwd2"
command = /$F
time = 1

[Command]
name = "holdback2"
command = /$B
time = 1

[Command]
name = "holdup2"
command = /$U
time = 1

[Command]
name = "holddown2"
command = /$D
time = 1

[Command]
name = "holda2"
command = /a
time = 1

[Command]
name = "holdb2"
command = /b
time = 1

[Command]
name = "holdc2"
command = /c
time = 1

[Command]
name = "holdx2"
command = /x
time = 1

[Command]
name = "holdy2"
command = /y
time = 1

[Command]
name = "holdz2"
command = /z
time = 1

[Command]
name = "holdstart2"
command = /s
time = 1

[Command]
name = "recovery2"
command = x+y
time = 1

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "QCFx2_2P"
command = ~D, DF, F, D, DF, F, x+y
time = 20

[Command]
name = "QCBx2_2P"
command = ~D, DB, B, D, DB, B, x+y
time = 20



[Command]
name = "QCFx2_P"
command = ~D, DF, F, D, DF, F, x
time = 20

[Command]
name = "QCFx2_P"
command = ~D, DF, F, D, DF, F, y
time = 20

[Command]
name = "QCBx2_P"
command = ~D, DB, B, D, DB, B, x
time = 20

[Command]
name = "QCBx2_P"
command = ~D, DB, B, D, DB, B, y
time = 20

[Command]
name = "QCFx2_K"
command = ~D, DF, F, D, DF, F, a
time = 20

[Command]
name = "QCFx2_K"
command = ~D, DF, F, D, DF, F, b
time = 20

[Command]
name = "QCBx2_K"
command = ~D, DB, B, D, DB, B, a
time = 20

[Command]
name = "QCBx2_K"
command = ~D, DB, B, D, DB, B, b
time = 20

[Command]
name = "QCFHCB_P"
command = ~D, DF, F, D, DB, B, x
time = 20
[Command]
name = "QCFHCB_P"
command = ~D, DF, F, D, DB, B, y
time = 20
[Command]
name = "QCFHCB_P"
command = ~D, F, D, B, x
time = 20
[Command]
name = "QCFHCB_P"
command = ~D, F, D, B, y
time = 20

[Command]
name = "QCBHCF_P"
command = ~D, DB, B, D, DF, F, x
time = 20
[Command]
name = "QCBHCF_P"
command = ~D, DB, B, D, DF, F, y
time = 20
[Command]
name = "QCBHCF_P"
command = ~D, B, D, F, x
time = 20
[Command]
name = "QCBHCF_P"
command = ~D, B, D, F, y
time = 20

[Command]
name = "Animality"
command = F,D,U
time = 15
[Command]
name = "r_Animality"
command = F,D,U
time = 15
[Command]
name = "Friendship"
command = ~F,~a,/B,y
time = 12

[Command]
name = "hissyfit"
command = ~30y

;-| Special Motions |------------------------------------------------------
[Command]
name = "HCB_p"
command = ~F, D, B, x
[Command]
name = "HCB_p"
command = ~F, D, B, y
[Command]
name = "HCB_p"
command = ~F, DF, D, DB, B, x
[Command]
name = "HCB_p"
command = ~F, DF, D, DB, B, y

[Command]
name = "HCF_p"
command = ~B, D, F, x
[Command]
name = "HCF_p"
command = ~B, D, F, y
[Command]
name = "HCF_p"
command = ~B, DB, D, DF, F, x
[Command]
name = "HCF_p"
command = ~B, DB, D, DF, F, y

[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_a"
command = ~F, D, DF, a

[Command]
name = "upper_b"
command = ~F, D, DF, b

[Command]
name = "rupper_x"
command = ~B, D, DB, x

[Command]
name = "rupper_y"
command = ~B, D, DB, y

[Command]
name = "rupper_a"
command = ~B, D, DB, a

[Command]
name = "rupper_b"
command = ~B, D, DB, b

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_k"
command = ~D, DB, B, a

[Command]
name = "QCB_k"
command = ~D, DB, B, b

[Command]
name = "QCF_k"
command = ~D, DF, F, a

[Command]
name = "QCF_k"
command = ~D, DF, F, b

[Command]
name = "QCB_xy"
command = ~D, DB, B, x+y

[Command]
name = "BF_a"
command = ~B, F, a
time = 10

[Command]
name = "BF_b"
command = ~B, F, b
time = 10

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

[Command]
name = "CD"
command = y+b
time = 1

[Command]
name = "dodge"
command = x+a
time = 1


;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "SupahJump"
;command = ~$D, $U
command = ~$D, $U
time = 5
buffer.time = 2

[Command]
name = "ChargedSupahJump"
;command = ~$D, $U
command = ~12$D, $U
time = 5
buffer.time = 2

[Command]
name = "upper_what"
command = ~15$D, $U, x
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, y
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, z
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, a
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, b
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, c
time = 10


;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

[State 0, AssertSpecial]
type = AssertSpecial
trigger1 = 1
flag = noairguard
ignorehitpause = 1


; The main purpose of having these next two controllers here at the top of
; StateDef -1 is to make sure the AI helper never changes to a different state,
; nor encounters any VarSets within State -1.
; But they also improve efficiency by preventing Mugen from wasting time
; processing the entire State -1 for the helper.
[State -1, AI Helper Check]
type = ChangeState
trigger1 = IsHelper(9741)
value = 9741

[State -1, AI Helper Check 2]
type = ChangeState
trigger1 = IsHelper(9742)
value = 9742

;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(9) = 0

[State -1, Combo condition Check]
type = VarSet
triggerall = ishelper
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = anim != 230
trigger2 = anim != 231
trigger2 = (stateno != 240 || anim != 240)
trigger2 = movecontact
trigger3 = stateno = 100 || stateno = 40
trigger4 = stateno = 0 || stateno = 11
trigger5 = stateno = [20,22]
trigger6 = stateno = 100 || stateno = 116
var(9) = 1

[State -1, AI Consideration reset]
type = VarSet
trigger1 = stateno != 40
var(52) = 0
ignorehitpause = 1

;triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= ifelse(anim=200,-84,-100)*const(size.yscale)

; For everyone


;===========================================================================

; Turn!
;[State -1, Stand Light Punch]
;type = ChangeState
;value = 100
;triggerall = ishelper
;triggerall = roundstate = 2
;triggerall = backedgedist < -20
;triggerall = var(16) = 0
;trigger1 = statetype = S
;trigger1 = var(9)

;---------------------------------------------------------------------------
; Turn!
[State -1, Turn]
type = ChangeState
value = 5
triggerall = ishelper
triggerall = roundstate = 2
trigger1 = statetype = S
trigger1 = stateno = 0 || stateno = 20 || stateno = 21
trigger1 = p2bodydist x < -10

[State -1, Get up and fight]
type = ChangeState
value = 12
triggerall = ishelper
triggerall = roundstate = 2
triggerall = statetype = C
triggerall = stateno != 12
trigger1 = p2bodydist x < -10
trigger2 = time >= 200

; You lose!
[State -1, Lose]
type = ChangeState
value = 170
triggerall = ishelper
trigger1 = statetype = S
trigger1 = var(9)
trigger1 = root, alive = 0

; RYou win!
[State -1, WIN]
type = ChangeState
value = 180
triggerall = ishelper
trigger1 = statetype != A
trigger1 = stateno = 0 || stateno = 11
trigger1 = root, stateno = [180,189]

[State 0, ]
type = VarSet
triggerall = ishelper
trigger1 = alive
trigger1 = var(10) > 0
var(10) = 0
ignorehitpause = 1
[State 0, ]
type = VarAdd
triggerall = ishelper
trigger1 = !alive
trigger1 = var(10) < 6
var(10) = 1
ignorehitpause = 1

[State 5150, 1]
type = parentvaradd
triggerall = ishelper
trigger1 = var(10) = 2
var(53) = 1
ignorehitpause = 1


;===========================================================================
;---------------------------------------------------------------------------
; Die!
[State -1, Collapse]
type = ChangeState
value = 5100
triggerall = ishelper
trigger1 = var(10) >= 250
trigger1 = stateno = 5001 || stateno = 5011

[State 0, ]
type = ScreenBound
triggerall = ishelper
trigger1 = stateno != [3000,3999]
trigger1 = stateno != [110,119]
value = (movetype=H && stateno != 5150)
;value = (stateno != [110,119])
movecamera = 0,0
ignorehitpause = 1

; Grappler AI

; Walk Forward
[State -1, Walk Forward]
type = ChangeState
value = 20
triggerall = ishelper
triggerall = roundstate = 2
trigger1 = var(11) = 1 || var(11) = 3 || var(11) = 6 || (var(11) = 2 && backedgedist <= -15)
trigger1 = stateno = [0,11]
;trigger1 = var(9) = 1
;trigger1 = stateno != 20
trigger1 = p2bodydist x >= 6
trigger2 = var(11) = 3
trigger2 = p2bodydist x>= 120
trigger2 = stateno = 21

[State -1, Walk Backward]
type = ChangeState
value = 21
triggerall = ishelper
triggerall = roundstate = 2
trigger1 = var(11) = 3
trigger1 = stateno = 20
;trigger1 = var(9) = 1
;trigger1 = stateno != 20
trigger1 = p2bodydist x <= 100
trigger1 = random<120-p2bodydist x

[State -1, ROLLIN']
type = VarSet
var(52) = 710
triggerall = ishelper
triggerall = roundstate = 2
triggerall = (facing != enemynear,facing)
trigger1 = var(11) = 6
trigger1 = stateno = 0 || stateno = 20 || stateno = 100
;trigger1 = var(9) = 1
;trigger1 = stateno != 20
trigger1 = p2bodydist x <= 80
trigger1 = random<50


[State -1, Stand Light Punch]
type = ChangeState
value = 100
triggerall = ishelper
triggerall = roundstate = 2
trigger1 = var(11) = 4 || var(11) = 6
trigger1 = stateno = [0,11]
;trigger1 = var(9) = 1
;trigger1 = stateno != 20
trigger1 = p2bodydist x >= 6

[State -1, Stand Light Punch]
type = ChangeState
value = 119
triggerall = ishelper
triggerall = roundstate = 2
trigger1 = var(11) = 7
trigger1 = stateno = [0,11]

[State AI, JUMP AROUND]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55) + (100*(stateno = 640)) + (100*(stateno = 240))
triggerall = ishelper
triggerall = roundstate = 2
triggerall = (statetype != A)
triggerall = var(11) = 5 || (var(11) = 6 && p2movetype=A)
trigger1 = ctrl || stateno = 100 || stateno = 40 || stateno = 0 || stateno = 20
trigger2 = stateno = 240 || stateno = 640 || stateno = 1402 || stateno = 1403
trigger2 = !(var(22) & floor(exp(0*ln(2)) + 0.5) ) || statetype != A
trigger2 = movecontact
var(52) = ifelse(p2bodydist x>=20,41,42)
ignorehitpause = 1

; AI-related stuff starts here

;[State -1, Combo Debugger]
;type = null;
;triggerall = command = "holdc"
;trigger1 = (stateno = 3350 && (anim != 3356||var(43) & floor(exp(1*ln(2)) + 0.5))) || stateno = 210
;trigger1 = (var(52):=3350)
;trigger2 = (prevstateno = 3350 && ctrl) || (prevstateno = 1110 && ctrl)
;trigger2 = (var(52):=200)
;trigger3 = (anim = 200)
;trigger3 = (var(52):=ifelse(var(43) & floor(exp(0*ln(2)) + 0.5)&&p2statetype!=A ,1110,200))
;trigger4 = (anim = 201)
;trigger4 = (var(52):=ifelse(p2statetype=A,240,1110))
;trigger5 = (anim = 247)
;trigger5 = (var(52):=ifelse(var(43) & floor(exp(3*ln(2)) + 0.5) ,1200,1300))
;ignorehitpause = 1

[State AI, Consider backing off]
type = VarSet
triggerall = var(55)
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = random < 200 + (123*(prevstateno = 440 && (p2stateno=[5070,5100]) ) )
triggerall = numenemy
triggerall = (p2stateno = [5110,5130]) || ((enemynear,time <= 10) && (enemynear,prevstateno = 5120))
triggerall = p2bodydist x <= 40
triggerall = screenpos x = [-20,340]
triggerall = var(11) = 2 || var(11) = 6
trigger1 = stateno != 40
trigger1 = ctrl || stateno = 0 || (stateno = [20,29]) || (stateno = 100)
trigger2 = random < 50
trigger2 = stateno = [200,499]
trigger2 = moveguarded
var(52) = ifelse(random<500,1300,105)

[State AI, Consider S.Y]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (9*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-8,-10),(40*const(size.xscale))-(5*movecontact)]
triggerall = p2dist y >= (-100*const(size.yscale)) - (enemynear,vel y*5)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= ifelse(p2bodydist x<=10&&p2statetype!=A,-80,-100)*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = var(11) = 4 || var(11) = 6
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 0 || (stateno = [20,29]) || (stateno = 100 && p2bodydist x <= 10)
trigger2 = (stateno = 200 && (anim=[200,202])) || (stateno = 210 && (anim=[210,212]))
trigger2 = animelemtime(4) <= 0
trigger2 = time > 6 || movecontact
trigger2 = (enemynear,gethitvar(hitcount) <= 4) || p2bodydist x <= (30*const(size.xscale))
var(52) = 210
ignorehitpause = 1
[State AI, Consider S.X]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (9*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-8,-10),(53*const(size.xscale))-(5*movecontact)]
triggerall = p2dist y >= (-70*const(size.yscale)) - (enemynear,vel y*5)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -90*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = var(11) = 4 || var(11) = 1 || var(11) = 6
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 0 || (stateno = [20,29]) || (stateno = 100 && random < 10)
trigger2 = (stateno = 200 && (anim=[200,202])) || (stateno = 210 && (anim=[210,212]))
trigger2 = animelemtime(4) <= 0
trigger2 = time > 6 || movecontact
trigger2 = (enemynear,gethitvar(hitcount) <= 4) || p2bodydist x <= (30*const(size.xscale))
var(52) = 200
ignorehitpause = 1
[State AI, Consider S.A]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (7*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-8,5),(86*const(size.xscale))-(5*movecontact)]
triggerall = p2dist y >= (-50*const(size.yscale)) - (enemynear,vel y*5)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -70*const(size.yscale) || (p2bodydist x <= 25 && p2statetype != A)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = var(11) = 3 || var(11) = 6
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H || var(11) = 3
trigger1 = ctrl || stateno = 0 || (stateno = [20,29]) || (stateno = 100)
var(52) = 230
ignorehitpause = 1
[State 0, AppendToClipboard]
type = AppendToClipboard
trigger1 = ishelper
text = "\nvar(11) = %d  55 = %d , dist = %d"
params = var(11),var(55),ceil(p2bodydist x)
ignorehitpause = 1
[State AI, Consider S.HA]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (7*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-8,5),(84*const(size.xscale))-(5*movecontact)]
triggerall = p2dist y >= (-80*const(size.yscale)) - (enemynear,vel y*5)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -90*const(size.yscale) || (p2bodydist x <= 25 && p2statetype != A)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = var(11) = 3 || var(11) = 6
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H || var(11) = 3
trigger1 = ctrl || stateno = 0 || (stateno = [20,29]) || (stateno = 100)
var(52) = 231
ignorehitpause = 1
[State AI, Consider S.B]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (6*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 50)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-8,-2),(69*const(size.xscale))-(11*movecontact)]
triggerall = p2dist y >= (-95*const(size.yscale)) - (enemynear,vel y*11)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -60*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = var(11) = 2 || var(11) = 3 || var(11) = 6 || (var(11) = 4 && movehit)
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H || var(11) = 3
trigger1 = ctrl || stateno = 0 || (stateno = [20,29]) || (stateno = 100)
trigger2 = stateno = 200 || stateno = 210
trigger2 = anim = 201 || anim = 211
trigger2 = movehit
var(52) = 240
ignorehitpause = 1

[State AI, Consider C.X]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (5*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-9,-12),(45*const(size.xscale))-(5*movecontact)]
triggerall = p2dist y >= (-40*const(size.yscale)) - (enemynear,vel y*5)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -50*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = var(11) = 6 || var(11) = 4
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 0 || (stateno = [20,29]) || (stateno = 100)
var(52) = 400
ignorehitpause = 1
[State AI, Consider C.Y]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (9*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-8,-10),(28*const(size.xscale))-(5*movecontact)]
triggerall = p2dist y >= (-100*const(size.yscale)) - (enemynear,vel y*5)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -44*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = var(11) = 3 || var(11) = 2 || var(11) = 5 || var(11) = 6
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H || var(11) = 3
trigger1 = ctrl || stateno = 0 || (stateno = [20,29]) || (stateno = 100)
trigger2 = (stateno = 210 && anim = 216 && animelemtime(5) <= 0)
trigger2 = movecontact && random < 20
var(52) = 410
ignorehitpause = 1
[State AI, Consider C.A]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (5*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-8,5),(77*const(size.xscale))-(5*movecontact)]
triggerall = p2dist y >= (-10*const(size.yscale)) - (enemynear,vel y*5)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = var(11) = 3 || var(11) = 6
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 0 || (stateno = [20,29]) || (stateno = 100)
var(52) = 430
ignorehitpause = 1
[State AI, Consider C.HA]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (5*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-8,-7),(43*const(size.xscale))-(6*movecontact)]
triggerall = p2dist y >= (-50*const(size.yscale)) - (enemynear,vel y*6)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -40*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = var(11) = 3 || var(11) = 6 || var(11) = 4
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 0 || (stateno = [20,29]) || (stateno = 100)
trigger2 = stateno = 430 || stateno = 400
trigger2 = movecontact
var(52) = 435
ignorehitpause = 1
[State AI, Consider C.B]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (5*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 50)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-8,-2),(72*const(size.xscale))-(11*movecontact)]
triggerall = p2dist y >= (-10*const(size.yscale)) - (enemynear,vel y*11)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = var(11) = 3 || var(11) = 6
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = ctrl || stateno = 0 || (stateno = [20,29]) || (stateno = 100)
var(52) = 440
ignorehitpause = 1

[State AI, J.P]
type = Varset
triggerall = numenemy
triggerall = var(52) = 0 || random < 123
triggerall = var(55)
triggerall = p2bodydist x = [-30+(vel x*5)+(enemynear,vel x*5),62+(vel x*5)+(enemynear,vel x*5)]
triggerall = P2dist y = [-47+(vel y*5)+(enemynear,vel y*5),70+(vel y*5)+(enemynear,vel y*5)]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5120]
triggerall = p2Statetype = A || vel y >= 0
triggerall = (stateno != [120,169])
triggerall = random < (5*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno = 50
var(52) = 600
[State AI, J.K]
type = Varset
triggerall = numenemy
triggerall = var(52) = 0 || random < 123
triggerall = var(55)
triggerall = p2bodydist x = [-48+(vel x*5)+(enemynear,vel x*5),48+(vel x*7)+(enemynear,vel x*5)]
triggerall = P2dist y = [-47+(vel y*5)+(enemynear,vel y*5),70+(vel y*7)+(enemynear,vel y*5)]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5120]
triggerall = p2Statetype = A || vel y >= 0
triggerall = (stateno != [120,169])
triggerall = random < (5*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = time >= 7-var(55) || random < 10
trigger1 = stateno = 50
var(52) = 630
[State AI, J.BONK]
type = Varset
triggerall = numenemy
triggerall = var(52) = 0 || random < 123
triggerall = var(55)
triggerall = p2bodydist x = [4+(enemynear,vel x*7),120+(enemynear,vel x*7)]
triggerall = P2dist y = [-17+(enemynear,vel y*7),80+(enemynear,vel y*7)]
triggerall = Statetype = A
triggerall = p2stateno != [5100,5120]
triggerall = p2Statetype = A || vel y >= 0
triggerall = (stateno != [120,169])
triggerall = random < (2*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = time >= 7-var(55) || random < 10
trigger1 = ctrl || stateno = 50
trigger2 = stateno = 600 || stateno = 630
trigger2 = movehit
var(52) = 610

[State AI, GO COMBO]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (20*(var(55)*var(55)))
trigger1 = stateno = 210 && anim = 215
trigger1 = movecontact
var(52) = 210
ignorehitpause = 1
[State AI, GO COMBO]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (20*(var(55)*var(55)))
trigger1 = stateno = 210 && anim = 216
trigger1 = movecontact
var(52) = 200
ignorehitpause = 1
[State AI, GO COMBO]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (20*(var(55)*var(55)))
trigger1 = stateno = 200 && anim = 206
trigger1 = movecontact
var(52) = 230
ignorehitpause = 1
[State AI, GO COMBO]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = random < (20*(var(55)*var(55)))
triggerall = movehit
trigger1 = stateno = 230 && anim = 235
trigger2 = (stateno = 240 && anim = 236)
trigger3 = random < (1*(var(55)*var(55)))
trigger3 = (stateno = 200 && anim = 206) || (stateno = 210 && anim = 216)
trigger3 = movecontact
var(52) = 240
ignorehitpause = 1

[State AI, Consider Slide Kicking]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (3*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 50)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,10),96*const(size.xscale)-(25*(movecontact>=1))]
triggerall = p2dist y >= -50*const(size.yscale) - (enemynear,vel y*5)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -55*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = var(11) = 2 || var(11) = 4 || var(11) = 6
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = stateno != 100 || random < 50
trigger1 = var(9)
var(52) = ifelse(random<500&&p2statetype!=A&&(p2bodydist x<=190*const(size.xscale)),1000,1010)
ignorehitpause = 1
[State AI, Consider Freezing]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (1.5*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 50)
triggerall = p2stateno != [5080,5130]
triggerall = p2bodydist x >= 100
triggerall = p2dist y >= -69*const(size.yscale) - (enemynear,vel y*5)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -40*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = !(var(43) & floor(exp(0*ln(2)) + 0.5) )
triggerall = p2stateno != 1105
triggerall = prevstateno != [1100,1110]
triggerall = var(11) = 2 || var(11) = 6
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = stateno != 100 || random < 60
trigger1 = var(9)
var(52) = ifelse(random<500,1100,1110)
ignorehitpause = 1
;[State AI, Consider Proving That The Old Republic was an investiment doomed to fail]
;type = VarSet
;triggerall = numenemy
;triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
;triggerall = var(55)
;triggerall = random < (2*(var(55)*var(55))) * ifelse(p2statetype=C,2,1) * ifelse(movehit,2,1)
;triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0)
;triggerall = p2stateno != [5080,5110]
;triggerall = p2bodydist x = [45,210]
;triggerall = statetype != A
;triggerall = time >= 7-var(55) || random < 10
;triggerall = !(var(43) & floor(exp(1*ln(2)) + 0.5) )
;triggerall = p2stateno != 1105
;triggerall = prevstateno != [1200,1230]
;trigger1 = stateno != 40
;trigger1 = stateno != 20 || random < 500 || p2movetype = H
;trigger1 = stateno != 100 || random < 60
;trigger1 = var(9)
;trigger1 = moveguarded
;trigger2 = stateno = 410 || stateno = 247
;trigger2 = movehit = [1,4]
;var(52) = ifelse((p2dist x=[85,135]),1220,ifelse((p2dist x=[135,185]),1210,ifelse((p2dist x=[185,245]),1230,1200)))
;var(52) = ifelse(stateno=410,1220,ifelse((p2dist x=[85,135]),1220,ifelse((p2dist x=[135,185]),1210,ifelse((p2dist x=[185,245]),1230,1200))))
;ignorehitpause = 1
[State AI, Consider Proving That The Old Republic was an investiment doomed to fail]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (2*(var(55)*var(55))) * ifelse(p2statetype!=S,2,1) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0)
triggerall = p2stateno != [5080,5110]
triggerall = p2bodydist x - (enemynear,vel x*16) = [45,85]
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = !(var(43) & floor(exp(1*ln(2)) + 0.5) )
triggerall = p2stateno != 1105
triggerall = prevstateno != [1200,1230]
triggerall = var(11) = 2 || var(11) = 6
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = stateno != 100 || random < 60
trigger1 = var(9)
trigger1 = moveguarded
trigger2 = stateno = 410 || stateno = 247 || ((stateno = [200,210]) && p2statetype = A)
trigger2 = movehit = [1,4]
var(52) = 1200
;var(52) = ifelse(stateno=410,1220,ifelse((p2dist x=[85,135]),1220,ifelse((p2dist x=[135,185]),1210,ifelse((p2dist x=[185,245]),1230,1200))))
ignorehitpause = 1
[State AI, Consider Proving That The Old Republic was an investiment doomed to fail]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (2*(var(55)*var(55))) * ifelse(p2statetype!=S,2,1) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0)
triggerall = p2stateno != [5080,5110]
triggerall = p2bodydist x - (enemynear,vel x*16) = [85,135]
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = !(var(43) & floor(exp(1*ln(2)) + 0.5) )
triggerall = p2stateno != 1105
triggerall = prevstateno != [1200,1230]
triggerall = var(11) = 2 || var(11) = 6
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = stateno != 100 || random < 60
trigger1 = var(9)
trigger1 = moveguarded
trigger2 = stateno = 410 || stateno = 247 || ((stateno = [200,210]) && p2statetype = A)
trigger2 = movehit = [1,4]
var(52) = ifelse(frontedgedist <=85,1200,1220)
;var(52) = ifelse(stateno=410,1220,ifelse((p2dist x=[85,135]),1220,ifelse((p2dist x=[135,185]),1210,ifelse((p2dist x=[185,245]),1230,1200))))
ignorehitpause = 1
[State AI, Consider Proving That The Old Republic was an investiment doomed to fail]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (2*(var(55)*var(55))) * ifelse(p2statetype!=S,2,1) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0)
triggerall = p2stateno != [5080,5110]
triggerall = p2bodydist x - (enemynear,vel x*16) = [135,185]
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = !(var(43) & floor(exp(1*ln(2)) + 0.5) )
triggerall = p2stateno != 1105
triggerall = prevstateno != [1200,1230]
triggerall = var(11) = 2 || var(11) = 6
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = stateno != 100 || random < 60
trigger1 = var(9)
trigger1 = moveguarded
trigger2 = stateno = 410 || stateno = 247 || ((stateno = [200,210]) && p2statetype = A)
trigger2 = movehit = [1,4]
var(52) = ifelse(frontedgedist <=85,1200,1220)
;var(52) = ifelse(stateno=410,1220,ifelse((p2dist x=[85,135]),1220,ifelse((p2dist x=[135,185]),1210,ifelse((p2dist x=[185,245]),1230,1200))))
ignorehitpause = 1
[State AI, Consider Proving That The Old Republic was an investiment doomed to fail]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (2*(var(55)*var(55))) * ifelse(p2statetype!=S,2,1) * ifelse(movehit,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0)
triggerall = p2stateno != [5080,5110]
triggerall = p2bodydist x - (enemynear,vel x*16) = [185,235]
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = !(var(43) & floor(exp(1*ln(2)) + 0.5) )
triggerall = p2stateno != 1105
triggerall = prevstateno != [1200,1230]
triggerall = var(11) = 2 || var(11) = 6
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = stateno != 100 || random < 60
trigger1 = var(9)
trigger1 = moveguarded
trigger2 = stateno = 410 || stateno = 247 || ((stateno = [200,210]) && p2statetype = A)
trigger2 = movehit = [1,4]
var(52) = ifelse(frontedgedist <=85,1200,1230)
;var(52) = ifelse(stateno=410,1220,ifelse((p2dist x=[85,135]),1220,ifelse((p2dist x=[135,185]),1210,ifelse((p2dist x=[185,245]),1230,1200))))
ignorehitpause = 1
[State AI, Consider Raging]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,250]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (1.5*(var(55)*var(55))) * ifelse(movehit,2,1)
triggerall = life < power/3
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 50)
triggerall = p2stateno != [5080,5130]
triggerall = p2dist y >= -90*const(size.yscale) - (enemynear,vel y*5)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -86*const(size.yscale)
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = !(var(43) & floor(exp(5*ln(2)) + 0.5) )
triggerall = prevstateno != [1500,1510]
triggerall = var(11) = 2 || var(11) = 6
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = stateno != 100 || random < 60
trigger1 = var(9)
var(52) = 1500
ignorehitpause = 1

[State AI, Consider Blowin' Out]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,255]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (3*(var(55)*var(55))) * ifelse(movehit,3,1)
triggerall = random < 300 + ((lifemax - life)/16)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 50) || var(11) = 7
triggerall = p2stateno != [5080,5140]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),120*const(size.xscale)-(16*(movecontact>=1))]
triggerall = p2dist y >= -90*const(size.yscale) - (enemynear,vel y*6)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -30*const(size.yscale)
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*16) + (enemynear, pos y) <= -16 ) || (p2stateno != [5030,5120])
triggerall = power >= 1000
triggerall = (p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A) || var(11) = 7
triggerall = p2stateno != [120,165]
triggerall = (prevstateno != [2000,3902]) || (stateno = [2000,3902])
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = p2stateno != 3005
triggerall = (enemynear,GetHitVar(hittime) >= 6 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = var(11) = 6 || var(11) = 7
triggerall = screenpos x = [-20,340]
trigger1 = anim != 20
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = stateno != 410
trigger1 = var(9)
trigger1 = !moveguarded || random < 80
trigger2 = (stateno = [1000,1010]) && (movehit)
trigger3 = stateno = 116
var(52) = 3000
ignorehitpause = 1
[State AI, Consider Uppercutting]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,255]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (3*(var(55)*var(55))) * ifelse(movehit,3,1)
triggerall = random < 300 + ((lifemax - life)/16)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || var(11) = 7
triggerall = p2stateno != [5080,5140]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),60*const(size.xscale)-(11*(movecontact>=1))]
triggerall = p2dist y >= ifelse(p2bodydist x<=40*const(size.xscale),-90,-10)*const(size.yscale) - (enemynear,vel y*11)
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*11) + (enemynear, pos y) <= -11 ) || (p2stateno != [5030,5120])
triggerall = power >= 1000
triggerall = (p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A) || var(11) = 7
triggerall = p2stateno != [120,165]
triggerall = (prevstateno != [2000,3902]) || (stateno = [2000,3902])
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = p2stateno != 3005
triggerall = (enemynear,GetHitVar(hittime) >= 8 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = var(11) = 6 || var(11) = 7
triggerall = screenpos x = [-20,340]
trigger1 = anim != 20
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = stateno != 410
trigger1 = var(9)
trigger1 = !moveguarded || random < 80
trigger2 = (stateno = [1000,1010]) && (movehit)
trigger3 = stateno = 116
var(52) = ifelse(random<500&&p2bodydist x<=50*const(size.xscale),3150,3050)
ignorehitpause = 1
[State AI, Consider Becoming a Bear]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,255]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (3*(var(55)*var(55))) * ifelse(movehit,3,1)
triggerall = random < 300 + ((lifemax - life)/16)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || var(11) = 7
triggerall = p2stateno != [5080,5140]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),ifelse(p2statetype!=A,90,40)*const(size.xscale)-(7*(movecontact>=1))]
triggerall = p2dist y >= ifelse(p2bodydist x<=40*const(size.xscale),-90,-10)*const(size.yscale) - (enemynear,vel y*7)
triggerall = ( p2dist y + (enemynear,const(size.head.pos.y) / ifelse(p2statetype=C,2,1) ) ) <= -30*const(size.yscale)
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*7) + (enemynear, pos y) <= -7 ) || (p2stateno != [5030,5120])
triggerall = power >= 1000
triggerall = (p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A) || var(11) = 7
triggerall = p2stateno != [120,165]
triggerall = (prevstateno != [2000,3902]) || (stateno = [2000,3902])
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = p2stateno != 3005
triggerall = (enemynear,GetHitVar(hittime) >= 8 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = var(11) = 6 || var(11) = 7
triggerall = screenpos x = [-20,340]
trigger1 = anim != 20
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = stateno != 410
trigger1 = var(9)
trigger1 = !moveguarded || random < 80
trigger2 = (stateno = [1000,1010]) && (movehit)
trigger3 = stateno = 116
var(52) = 3300
ignorehitpause = 1
[State AI, Consider Turning The Victim Into A Baby]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,255]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (1.5*(var(55)*var(55))) * ifelse(movehit,3,1)
triggerall = random < 300 + ((lifemax - life)/16)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || var(11) = 7
triggerall = p2stateno != [5080,5110]
triggerall = enemynear, stateno != 5120 || enemynear, animtime <= -3
triggerall = p2bodydist x >= 160
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*39) + (enemynear, pos y) <= -39 ) || (p2stateno != [5030,5120])
triggerall = power >= 1000
triggerall = (p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A) || var(11) = 7
triggerall = (prevstateno != [2000,3902]) || (stateno = [2000,3902])
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = p2stateno != 3005
triggerall = var(11) = 6
triggerall = screenpos x = [-20,340]
trigger1 = anim != 20
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = stateno != 410
trigger1 = var(9)
trigger2 = stateno = 116
var(52) = 3250
ignorehitpause = 1
[State AI, Consider A Grapple Super]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,255]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (3*(var(55)*var(55)))
triggerall = random < 300 + ((lifemax - life)/16)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 450) || var(11) = 7
triggerall = p2stateno != [5080,5140]
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),34*const(size.xscale)-(5*(movecontact>=1))]
triggerall = p2dist y >= -5*const(size.yscale) - (enemynear,vel y*5)
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*5) + (enemynear, pos y) <= -5 ) || (p2stateno != [5030,5120])
triggerall = power >= 1000
triggerall = (p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A) || var(11) = 7
triggerall = p2stateno != [120,165]
triggerall = (prevstateno != [2000,3902]) || (stateno = [2000,3902])
triggerall = statetype != A
triggerall = p2statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = p2stateno != 3005
triggerall = (enemynear,GetHitVar(hittime) >= 5 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = var(11) = 6 || var(11) = 1 || var(11) = 7
triggerall = screenpos x = [-20,340]
trigger1 = anim != 20
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = stateno != 410
trigger1 = var(9)
trigger1 = !moveguarded || random < 80
trigger2 = (stateno = [1000,1010]) && (movehit)
trigger3 = stateno = 116
var(52) = 3100
ignorehitpause = 1
[State AI, Consider Ripping Dem Spines]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || ( (random < 80+var(55)) && (var(52)!=[200,255]) && (var(52)!=[400,450]) )
triggerall = var(55)
triggerall = random < (3*(var(55)*var(55))) * ifelse(movehit,3,1)
triggerall = random < 300 + ((lifemax - life)/16)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 150) || var(11) = 7
triggerall = p2stateno != [5080,5140]
triggerall = enemynear,prevstateno != 5120
triggerall = p2bodydist x = [ifelse(p2statetype!=A,-5,0),40*const(size.xscale)-(11*(movecontact>=1))]
triggerall = p2dist y >= -80*const(size.yscale) - (enemynear,vel y*3)
triggerall = ( enemynear, vel y <= 0 ) || ( (enemynear, vel y*3) + (enemynear, pos y) <= -3 ) || (p2stateno != [5030,5120])
triggerall = power >= 3000
triggerall = (p2movetype = H) || (enemynear, ctrl = 0) || (enemynear, statetype = A) || var(11) = 7
triggerall = p2stateno != [120,165]
triggerall = (prevstateno != [2000,3902]) || (stateno = [2000,3902])
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = p2stateno != 3005
triggerall = (enemynear,GetHitVar(hittime) >= 3 ) || (p2movetype != H) || (p2statetype = A) || (p2stateno != [5000,5025])
triggerall = var(11) = 6 || var(11) = 7
triggerall = screenpos x = [-20,340]
trigger1 = anim != 20
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 500 || p2movetype = H
trigger1 = stateno != 410
trigger1 = var(9)
trigger1 = !moveguarded || random < 80
trigger2 = (stateno = [1000,1010]) && (movehit)
trigger3 = stateno = 3050
trigger4 = stateno = 116
var(52) = 3500
ignorehitpause = 1
[State AI, Consider Being Brutal]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || (random < 80+var(55))
triggerall = var(55)
triggerall = random < (15*(var(55)*var(55)))
triggerall = random < 300 + ((lifemax - life)/16)
triggerall = p2statetype != A
triggerall = power >= 1000
triggerall = movehit
triggerall = var(11) = 6 || (var(11) = 4 && random < 100)
trigger1 = stateno = 210 && anim = 215
trigger2 = stateno = 3350
var(52) = 3350
ignorehitpause = 1

[State AI, Consider a Counter]
type = VarSet
triggerall = var(55)
triggerall = random < (2*(var(55)*var(55))) * ifelse(moveguarded,3,1)
triggerall = ((p2movetype = A) && (EnemyNear, Facing != Facing))
triggerall = p2movetype != H
triggerall = statetype != A
triggerall = power >= 1000
triggerall = p2bodydist x <= 100
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
triggerall = var(11) = 2
var(5) = 3200
[State AI, Consider watching this again]
type = VarSet
triggerall = var(55)
triggerall = random < (15*(var(55)*var(55)))
triggerall = screenpos x = [-20,340]
trigger1 = stateno = 3050
trigger1 = movehit
trigger1 = enemynear, vel x >= 0
trigger1 = p2bodydist x = [-10,ifelse(var(0)>=3,60,77)*const(size.xscale)]
var(52) = ifelse(var(0)>=3,3150,3050)

[State AI, Consider Throwing]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 900
triggerall = var(55)
triggerall = random < (15*(var(55)*var(55)))
triggerall = p2stateno != [5080,5130]
triggerall = abs(p2bodydist x) < 6
triggerall = statetype != A
;triggerall = p2movetype != H
triggerall = p2statetype != A
triggerall = var(8) = 0
triggerall = prevstateno != 1400
triggerall = var(11) = 1 || var(11) = 6
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = ctrl || stateno = 0 || (stateno = [20,29]) || (stateno = 100)
trigger2 = (stateno = 240 && anim = 235) || (stateno = 247) || ((stateno = [200,210]) && random < 50)
trigger2 = movehit
var(52) = ifelse(power>=1000&&random<100,3100,ifelse(random<500||var(8)!=0||stateno>=200||p2movetype=H,1400,200))
ignorehitpause = 1

[State AI, Consider Advancing]
type = VarSet
triggerall = var(55)
triggerall = var(52) = 0 || random < 80+var(55)
triggerall = random < (33*var(55))
triggerall = ((enemynear, ctrl = 0) && p2movetype != A) || (p2movetype = A && (enemynear, facing = facing))
triggerall = (p2stateno != [5080,5130]) || (p2bodydist x = [45,100])
triggerall = p2bodydist x >= 45
triggerall = statetype != A
triggerall = time >= 7-var(55) || random < 10
triggerall = var(11) = 5 || var(11) = 4 || var(11) = 6
trigger1 = stateno != 40
trigger1 = stateno != 100
trigger1 = ctrl || stateno = 0 || (stateno = [20,29]) || (stateno = 100)
trigger1 = !moveguarded
var(52) = ifelse(random<200,41,100)
[State AI, Consider jumping in]
type = VarSet
triggerall = numenemy
triggerall = var(52) = 0 || random < 80+var(55) + (100*(stateno = 640)) + (100*(stateno = 240))
triggerall = var(55)
triggerall = p2stateno != [5080,5130]
triggerall = statetype != A || stateno = 640
triggerall = p2statetype = A && p2movetype = H
triggerall = (enemynear, pos y <= -45)
triggerall = var(11) = 3 || var(11) = 6
trigger1 = ctrl || stateno = 100 || stateno = 40
trigger2 = stateno = 240 || stateno = 640 || stateno = 1402 || stateno = 1403
trigger2 = !(var(22) & floor(exp(0*ln(2)) + 0.5) ) || statetype != A
trigger2 = movecontact
var(52) = ifelse(p2bodydist x>=20,ifelse(p2bodydist x>=160,44,41),42)
ignorehitpause = 1

[State AI, Consider Trapping]
type = VarSet
triggerall = (var(52) = 0 || random < 80) && (var(52) != [100,3999])
triggerall = var(55)
triggerall = random < (1*(var(55)*var(55))) * ifelse(stateno = 52,2.5,1) / ifelse(statetype=A,2,1)
triggerall = ((p2movetype != A && enemynear, numproj = 0) || (EnemyNear, Facing = Facing) || (EnemyNear, moveguarded >= 8) || (var(51)) || (!InGuardDist) ) || (p2movetype!= A && enemynear, ctrl = 0) || (random < 222)
triggerall = p2bodydist x >= 40 || p2stateno = 5120 || p2statetype = A
;triggerall = statetype != A
triggerall = !numhelper(1300)
triggerall = p2stateno != 1105
triggerall = var(11) = 2
triggerall = screenpos x = [-20,340]
trigger1 = stateno != 40
trigger1 = stateno != 20 || random < 100 || p2movetype = H
trigger1 = ctrl || stateno = 0 || (stateno = [20,29]) || (stateno = 100 && p2movetype = A)
trigger2 = var(9)
trigger2 = moveguarded
var(52) = 1300
ignorehitpause = 1

[State AI, Guard S]
type = ChangeState
triggerall = stateno != 40
triggerall = random < 125*var(55)
triggerall = (var(55)) && (StateType != A) && (EnemyNear, Facing != Facing) && (var(50)<40)
triggerall = var(11) = 6
triggerall = ctrl || stateno = 0 || (stateno = [20,29]) || (stateno = 100)
trigger1 = (P2StateType != C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = ifelse(random<50&&p2bodydist x<=100&&backedgedist >= 66&&(stateno!=[120,159]),1300,130)

[State AI, Guard L]
type = ChangeState
triggerall = stateno != 40
triggerall = random < 125*var(55)
triggerall = (var(55)) && (StateType != A) && (EnemyNear, Facing != Facing) && (var(50)<40)
triggerall = var(11) = 6
triggerall = ctrl || stateno = 0 || (stateno = [20,29]) || (stateno = 100)
trigger1 = (P2StateType = C) && (((P2MoveType = A) && (inguarddist)) || (EnemyNear, NumProj > 0))
value = ifelse(random<50&&p2bodydist x<=100&&backedgedist >= 66&&(stateno!=[120,159]),1300,131)

; AI-related stuff ends here

;---------------------------------------------------------------------------
;Light Kung Fu Blow
;[State -1, Light Kung Fu Blow]
;type = ChangeState
;value = 1200
;triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "QCB_x",command = "QCF_x")) || var(52) = 1200
;trigger1 = var(9) ;Use combo condition (above)
[State -1, TRAINMUGEN]
type = ChangeState
value = 3150
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "QCFHCB_P",command = "QCBHCF_P")) || var(52) = 3150
triggerall = power >= 1000
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1100]) || (stateno = 230) || (stateno = 240)
trigger2 = movecontact
trigger3 = (stateno = 3250 && animelemtime(5) >= 0) || (stateno = 3050 && animelemtime(9) >= 6)
[State -1, WELL BLOW ME DOWN]
type = ChangeState
value = 3000
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "QCBx2_P",command = "QCFx2_P")) || var(52) = 3000
triggerall = power >= 1000
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1100]) || (stateno = 230) || (stateno = 240)
trigger2 = movecontact
trigger3 = (stateno = 3250 && animelemtime(5) >= 0) || (stateno = 3050 && animelemtime(9) >= 6)
[State -1, WHAT A RIPOFF]
type = ChangeState
value = 3500
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "QCFx2_2P",command = "QCBx2_2P")) || var(52) = 3500
triggerall = power >= 3000
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1100]) || (stateno = 230) || (stateno = 240)
trigger2 = movecontact
trigger3 = (stateno = 3250 && animelemtime(5) >= 0)
[State -1, JOHNNY CAGE]
type = ChangeState
value = 3050
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "QCFx2_P",command = "QCBx2_P")) || var(52) = 3050
triggerall = power >= 1000
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1100]) || (stateno = 230) || (stateno = 240)
trigger2 = movecontact
trigger3 = (stateno = 3250 && animelemtime(5) >= 0)
[State -1, RAIDEN]
type = ChangeState
value = 3100
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "QCFx2_K",command = "QCBx2_K")) || var(52) = 3100
triggerall = power >= 1000
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1100]) || (stateno = 230) || (stateno = 240)
trigger2 = movecontact
trigger3 = (stateno = 3250 && animelemtime(5) >= 0) || (stateno = 3050 && animelemtime(9) >= 6)
[State -1, BABALITY]
type = ChangeState
value = 3250
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "QCBx2_K",command = "QCFx2_K")) || var(52) = 3250
triggerall = power >= 1000
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1100]) || (stateno = 230) || (stateno = 240)
trigger2 = movecontact

[State -1, DUN DUN DUNN]
type = ChangeState
value = 3004
triggerall = (ifelse((anim!=[5,6]),command = "HCB_p",command = "HCF_p")) || var(52) = 3004
;triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "HCB_p",command = "HCF_p")) || var(52) = 3004
trigger1 = stateno = 3000
trigger1 = animelemtime(2) >= 16

[State -1, HHHNNNNNNNNNGGGGGG]
type = ChangeState
value = 1400
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "HCB_p",command = "HCF_p")) || var(52) = 1400
trigger1 = var(9) ;Use combo condition (above)

[State -1, TORTANIC]
type = ChangeState
value = 1200
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "upper_x",command = "rupper_x")) || var(52) = 1200
triggerall = numhelper(1200)=0
trigger1 = var(9) ;Use combo condition (above)
[State -1, TORTANIC]
type = ChangeState
value = 1210
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "upper_y",command = "rupper_y")) || var(52) = 1210
triggerall = numhelper(1200)=0
trigger1 = var(9) ;Use combo condition (above)
[State -1, TORTANIC]
type = ChangeState
value = 1220
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "upper_a",command = "rupper_a")) || var(52) = 1220
triggerall = numhelper(1200)=0
trigger1 = var(9) ;Use combo condition (above)
[State -1, TORTANIC]
type = ChangeState
value = 1230
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "upper_b",command = "rupper_b")) || var(52) = 1230
triggerall = numhelper(1200)=0
trigger1 = var(9) ;Use combo condition (above)
[State -1, Iceball]
type = ChangeState
value = 1100
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "QCF_x",command = "QCB_x")) || var(52) = 1100
triggerall = numhelper(1100)=0
trigger1 = var(9) ;Use combo condition (above)
[State -1, Iceball]
type = ChangeState
value = 1110
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "QCF_y",command = "QCB_y")) || var(52) = 1110
triggerall = numhelper(1100)=0
trigger1 = var(9) ;Use combo condition (above)
[State -1, IceClone]
type = ChangeState
value = 1300
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "QCB_k",command = "QCF_k")) || var(52) = 1300
triggerall = !(var(43) & floor(exp(3*ln(2)) + 0.5) ) || !numhelper(1300)
trigger1 = var(9) ;Use combo condition (above)
trigger2 = statetype = A
trigger2 = ctrl
trigger3 = stateno = 600 || stateno = 630
trigger3 = movecontact

[State -1, Sub Zero Kick]
type = ChangeState
value = 1000
triggerall = (var(55)<5 && command = "BF_a") || var(52) = 1000
trigger1 = var(9) ;Use combo condition (above)

[State -1, Cage Kick]
type = ChangeState
value = 1010
triggerall = (var(55)<5 && command = "BF_b") || var(52) = 1010
trigger1 = var(9) ;Use combo condition (above)

[State -1, BRUTALITY]
type = ChangeState
value = ifelse(anim=3357,3351,3350)
triggerall = stateno = 210 || stateno = 3350
triggerall = movehit
trigger1 = power >= 1000
trigger1 = anim = 215
trigger1 = (command = "a") || var(52) = 3350
trigger2 = anim = 3350
trigger2 = (command = "b") || var(52) = 3350
trigger3 = anim = 3351
trigger3 = (command = "x") || var(52) = 3350
trigger4 = anim = 3352
trigger4 = (command = "y") || var(52) = 3350
trigger5 = anim = 3353
trigger5 = (command = "b") || var(52) = 3350
trigger6 = anim = 3354
trigger6 = (command = "y") || var(52) = 3350
trigger7 = anim = 3355
trigger7 = (command = "y") || var(52) = 3350
trigger8 = anim = 3356
trigger8 = (command = "x") || var(52) = 3350
trigger9 = anim = 3357
trigger9 = (command = "y") || var(52) = 3350
ignorehitpause = (stateno=3350)

[State -1, FRIENDSHIP]
type = ChangeState
value = 3200
triggerall = (var(55)<5 && command = "Friendship") || var(52) = 3200
triggerall = power >= 1000
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1100]) || (stateno = 230) || (stateno = 240)
trigger2 = movecontact
trigger3 = stateno = [200,440]
trigger3 = statetype != A

[State -1, ANIMALITY]
type = ChangeState
value = 3300
triggerall = (var(55)<5 && ifelse((anim!=[5,6]),command = "Animality",command = "r_Animality")) || var(52) = 3300
triggerall = power >= 1000
trigger1 = var(9) ;Use combo condition (above)
trigger2 = (stateno = [1000,1100]) || (stateno = 230) || (stateno = 240)
trigger2 = movecontact

[State -1, RAGE]
type = ChangeState
value = 1500
triggerall = (var(55)<5 && command="hissyfit") || var(52) = 1500
triggerall = life <= floor(power/3)
trigger1 = var(9)

[State -1, AKUMA]
type = ChangeState
value = 700
triggerall = (!var(55) && command = "CD")  || var(52) = 700
triggerall = power >= 500
triggerall = statetype != A
trigger1 = stateno = [150,154]

[State -1, DODGE IT]
type = ChangeState
value = 711
triggerall = ((command = "dodge" && command = "holdback") && !var(55)) || var(52) = 711
triggerall = statetype != A
trigger1 = ctrl || stateno = 100
trigger2 = power >= 500
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = anim != 230
trigger2 = anim != 231
trigger2 = movecontact
trigger2 = !var(55) || moveguarded
trigger3 = power >= 1000
trigger3 = (stateno = [120,155])

[State -1, DODGE IT]
type = ChangeState
value = 710
triggerall = ((command = "dodge" && command != "holdback") && !var(55)) || var(52) = 710
triggerall = statetype != A
trigger1 = ctrl || stateno = 100
trigger2 = power >= 500
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = anim != 230
trigger2 = anim != 231
trigger2 = movecontact
trigger2 = !var(55) || moveguarded
trigger3 = power >= 1000
trigger3 = (stateno = [120,155])


;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = stateno != 100
triggerall = (command = "FF") || (var(52) = 100)
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = power >= 1000
trigger2 = !var(55) || (var(52) = 100)
trigger2 = stateno = [200,430]
trigger2 = movecontact

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = (var(55)<5 && command = "BB") || var(52) = 105
trigger1 = var(9) ;Use combo condition (above)

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = ishelper
triggerall = (var(55)<5 && (command = "x" && command != "holddown")) || var(52) = 200
trigger1 = statetype != A
trigger1 = ctrl || stateno = 100 || (stateno = [0,12]) || (stateno = [20,29])
trigger2 = (stateno = 200 && (anim=[200,202])) || (stateno = 210 && (anim=[210,212]))
trigger2 = animelemtime(4) <= 0
trigger2 = time > 6 || movecontact
trigger3 = (stateno = 210 && anim = 216 && animelemtime(5) <= 0)
trigger3 = movecontact

[State -1, Stand Hard Punch]
type = ChangeState
value = 210
triggerall = ishelper
triggerall = (var(55)<5 && (command = "y" && command != "holddown")) || var(52) = 210
trigger1 = statetype != A
trigger1 = ctrl || stateno = 100 || (stateno = [0,12]) || (stateno = [20,29])
trigger2 = (stateno = 200 && (anim=[200,202])) || (stateno = 210 && (anim=[210,212]))
trigger2 = animelemtime(4) <= 0
trigger2 = time > 6 || movecontact
trigger3 = (stateno = 210 && anim = 215 && animelemtime(5) <= 0)
trigger3 = movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
;LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = ishelper
triggerall = (var(55)<5 && (command = "a" && command != "holddown")) || (var(52) = [230,231])
trigger1 = statetype != A
trigger1 = ctrl || stateno = 100 || (stateno = [0,12]) || (stateno = [20,29])
trigger2 =(stateno = 210 && anim = 216 && animelemtime(5) <= 0) || (stateno = 200 && anim = 206 && animelemtime(4) <= 0)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
;LbN
[State -1, Stand Hard Kick]
type = ChangeState
value = 240
triggerall = ishelper
triggerall = (var(55)<5 && (command = "b" && command != "holddown")) || var(52) = 240
trigger1 = statetype != A
trigger1 = ctrl || stateno = 100 || (stateno = [0,12]) || (stateno = [20,29])
trigger2 = stateno = 230 && anim = 235 && animelemtime(5) <= 0
trigger2 = movecontact

;---------------------------------------------------------------------------
;Stand Light Kick
;LbN
[State -1, Stand Knockdown]
type = ChangeState
value = 245
triggerall = ishelper
trigger1 = (var(55)<5 && (command = "b" && command = "holdback")) || var(52) = 240
trigger1 = (stateno = 240 && anim = 236 && animelemtime(5) <= 0) || (stateno = 210 && anim = 216 && animelemtime(5) <= 0) || (stateno = 200 && anim = 206 && animelemtime(4) <= 0)
trigger1 = movecontact
trigger2 = (var(55)<5 && (command = "b")) || var(52) = 240
trigger2 = (stateno = 210 && anim = 211) || (stateno = 200 && anim = 201)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = ishelper
triggerall = (command = "start") || var(52) = 195 || (var(58) = -2 && winko && !var(48))
triggerall = stateno != 195
trigger1 = statetype != A
trigger1 = ctrl || stateno = 100 || (stateno = [0,12]) || (stateno = [20,29])

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = ishelper
triggerall = (var(55)<5 && (command = "x" && command = "holddown")) || var(52) = 400
trigger1 = statetype != A
trigger1 = ctrl || stateno = 100 || (stateno = [0,12]) || (stateno = [20,29])

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 410
triggerall = ishelper
triggerall = (var(55)<5 && (command = "y" && command = "holddown")) || var(52) = 410
trigger1 = statetype != A
trigger1 = ctrl || stateno = 100 || (stateno = [0,12]) || (stateno = [20,29])
trigger2 = (stateno = 210 && anim = 216 && animelemtime(5) <= 0)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 435
triggerall = ishelper
triggerall = (var(55)<5 && (command = "a" && command = "holddown" && command = "holdback")) || var(52) = 435
trigger1 = statetype != A
trigger1 = ctrl || stateno = 100 || (stateno = [0,12]) || (stateno = [20,29])
trigger2 = stateno = 430 || stateno = 400
trigger2 = movecontact

[State -1, Crouching Light Punch]
type = ChangeState
value = 430
triggerall = ishelper
triggerall = (var(55)<5 && (command = "a" && command = "holddown")) || var(52) = 430
trigger1 = statetype != A
trigger1 = ctrl || stateno = 100 || (stateno = [0,12]) || (stateno = [20,29])

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 440
triggerall = ishelper
triggerall = (var(55)<5 && (command = "b" && command = "holddown")) || var(52) = 440
trigger1 = statetype != A
trigger1 = ctrl || stateno = 100 || (stateno = [0,12]) || (stateno = [20,29])

;---------------------------------------------------------------------------
;Jump Punch
[State -1, Jump Bonk]
type = ChangeState
value = 610
triggerall = ishelper
triggerall = (var(55)<5 && (command = "y" && command = "holddown")) || var(52) = 610
trigger1 = statetype = A
trigger1 = ctrl || stateno = 50
trigger2 = stateno = 600 || stateno = 630
trigger2 = movecontact

[State -1, Jump Punch]
type = ChangeState
value = 600
triggerall = ishelper
triggerall = (var(55)<5 && (command = "x" || command = "y")) || var(52) = 600
trigger1 = statetype = A
trigger1 = ctrl || stateno = 50

[State -1, Jump Kick]
type = ChangeState
value = 630
triggerall = ishelper
triggerall = (var(55)<5 && (command = "a" || command = "b")) || var(52) = 630
trigger1 = statetype = A
trigger1 = ctrl || stateno = 50

[State -1, Jump]
type = ChangeState
value = 40
triggerall = ishelper
triggerall = (var(55)<5 && command = "holdup") || (var(52) = [40,43])
trigger1 = stateno = 100
trigger2 = stateno = 410
trigger2 = movehit
trigger3 = ishelper
trigger3 = stateno = [0,23]


